@@ -27,14 +27,16 @@ async def run():
     arg_parser.add_argument('-f', '--format', dest='formats', type=str, nargs="+", choices=formats, help='Format to convert to', required=True)
     arg_parser.add_argument('-o', '--output', dest='output', type=Path, help='Specify output directory (optional)', default=Path.cwd())
     arg_parser.add_argument('--github-auth', dest='github_auth', type=str, help='Github Auth in format username:token')
-    arg_parser.add_argument('--modrinth-search', dest="modrinth_search", type=str, choices=("exact", "accurate", "loose"), help=modrinth_search_help, default="exact")
-    arg_parser.add_argument('--exclude-providers', dest="excluded_providers", type=str, nargs="+", choices=providers, help="List of providers you which to exclude from search", default=str())
+    arg_parser.add_argument('--modrinth-search', dest='modrinth_search', type=str, choices=('exact', 'accurate', 'loose'), help=modrinth_search_help, default='exact')
+    arg_parser.add_argument('--exclude-providers', dest='excluded_providers', type=str, nargs="+", choices=providers, help='List of providers you which to exclude from search', default=str())
+    arg_parser.add_argument('--exclude-forbidden', dest='ignore_CF_flag', action='store_false', help='Exclude mods which not allowed for distribution from CurseForge search (disabled by default)')
     args = arg_parser.parse_args()
 
     if not args.input.exists(): exit("Invalid input!")
 
     ResourceAPI.modrinth_search_type = args.modrinth_search
     ResourceAPI.excluded_providers = args.excluded_providers
+    ResourceAPI.ignore_CF_flag = args.ignore_CF_flag
 
     if args.github_auth:
         login, password = args.github_auth.split(":")
